=======
Credits
=======

Core Developers
----------------

* Alex Kain <lxkain@gmail.com>
* Tuan Dinh <tdinh@sensoryinc.com>
* Ognyan Moore <ognyan.moore@gmail.com>

Contributors
------------

None yet. Why not be the first?
